import setuptools
from setuptools import setup

setup(
    name='AbdallahRadwanLib',
    version='0.2',    
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",        
    ],
    url='https://github.com/abdorado1984/AbdallahPackage',
    license='MIT',
    author='Abdallah Radwan',
    author_email='AbdallahRadwan2011@gmail.com',
    description='My First Package for Python Projects with PyPI Package - October 2024',  
)

# packages=['arUtilities'],
